==> clicknium-0.1.0-py3-none-win32.whl: clicknium/_clicknium.py <==
import sys
from typing import List, Union
from clicknium.common.enums import WindowMode, BrowserType
from clicknium.core.models.config.config import Config
from clicknium.core.models.window.window import Window
from clicknium.core.models.java.java import Java
from clicknium.core.models.sap.sap import Sap
from clicknium.core.models.uielement import UiElement
from clicknium.core.models.web.basewebdriver import BaseWebDriver
from clicknium.core.models.web.webdriver import WebDriver
from clicknium.core.service.invokerservice import _InvokerService
from clicknium.locator import _Locator

if sys.version_info >= (3, 8):
    from typing import Literal
else: 
    from typing_extensions import Literal

class _Clicknium():

    config = Config()
    ie = BaseWebDriver(BrowserType.IE)
    chrome = WebDriver(BrowserType.Chrome)
    firefox = WebDriver(BrowserType.FireFox)
    edge = WebDriver(BrowserType.Edge)
    window = Window()
    sap = Sap()
    java = Java()    

    @staticmethod
    def find_element(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        window_mode: Literal["auto", "topmost", "noaction"] = WindowMode.Auto
    ) -> UiElement:

        """
            Return UI element defined by the given locator.

            Remarks: 

                1.Use "Ctrl + F10" to record locator.

                2.Import window_mode type definition with " from clicknium.common.enums import * ".
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q.  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clickcorp.com/documents#automation/parametric_locator.  

                window_mode: define whether to set the UI element's parent window to topmost before an action is invoked.  
                    auto: default value, means setting the window to topmost if it is not, and doing nothing if it is already topmost;  
                    topmost: always set the window to topmost;  
                    noaction: doing nothing to topmost mode.  
 
            Returns:
                UiElement object.  
        """
        ele = _InvokerService.find_element(locator, locator_variables, window_mode)
        return UiElement(ele)

    @staticmethod
    def find_elements(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        timeout: int = 30
    ) -> List[UiElement]:

        """
            Return list of all matched UI elements by the given locator.

            Remarks: 

                1.Use "Ctrl + F10" to record locator.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clickcorp.com/documents#automation/parametric_locator  

                timeout: timeout for the operation, unit is second, default value is 30 seconds.  
 
            Returns:
                List of matched UiElement object.  
        """
        elements = []
        results = _InvokerService.find_elements(locator, locator_variables, timeout)
        if results:
            for element in results:
                elements.append(UiElement(element))
        return elements

    ui = find_element

    @staticmethod
    def send_hotkey(hotkey: str) -> None:
        """
            Send hotkey to the cursor's current position.
 
            Parameters:
                hotkey: hotkey string represents one key or combined keys. For example, to represent the letter A, input string "A". To represent the letters A, B, and C, input paremeter "ABC". For special keys, please refer to [hotkeys](https://docs.microsoft.com/en-au/dotnet/api/system.windows.forms.sendkeys?view=windowsdesktop-6.0#remarks).
                                
            Returns:
                None
        """
        _InvokerService.send_hotkey(hotkey)

    @staticmethod
    def send_text(text: str) -> None:
        """
            Send text to the cursor's current position.  
 
            Parameters:

                text[Requried]: text string to be sent.  

            Returns:
                None
        """
        _InvokerService.send_text(text)

    @staticmethod
    def wait_disappear(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        wait_timeout: int = 30
    ) -> bool:
        """
            Wait for the UI element to disappear within specified timeout.  
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clickcorp.com/documents#automation/parametric_locator  

                wait_timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                bool, return True if the element disappears within timeout otherwise return False.
        """ 
        result = _InvokerService.wait_disappear(locator, locator_variables, wait_timeout)
        return True if result else False

    @staticmethod
    def wait_appear(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        wait_timeout: int = 30
    ) -> UiElement:
        """
            Wait for the UI element to appear and return it within specified timeout.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clickcorp.com/documents#automation/parametric_locator  

                wait_timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                UiElement object, or None if the element does not appear.  
        """      
        ele = _InvokerService.wait_appear(locator, locator_variables, wait_timeout)
        if ele:
            return UiElement(ele)
        return None

    @staticmethod
    def is_existing(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        timeout: int = 30
    ) -> bool:
        """
            Check whether the UI element exists or not.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clickcorp.com/documents#automation/parametric_locator  

                timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                Return True if the UI element exists, otherwise return False.
        """        
        result = _InvokerService.is_existing(locator, locator_variables, timeout)
        return True if result else False

==> clicknium-0.1.2-py3-none-win32.whl: clicknium/_clicknium.py <==
import sys
from typing import List, Union
from clicknium.common.enums import WindowMode, BrowserType
from clicknium.common.utils import Utils
from clicknium.core.models.config.config import Config
from clicknium.core.models.window.window import Window
from clicknium.core.models.java.java import Java
from clicknium.core.models.sap.sap import Sap
from clicknium.core.models.uielement import UiElement
from clicknium.core.models.web.basewebdriver import BaseWebDriver
from clicknium.core.models.web.webdriver import WebDriver
from clicknium.core.service.invokerservice import _InvokerService
from clicknium.locator import _Locator

if sys.version_info >= (3, 8):
    from typing import Literal
else: 
    from typing_extensions import Literal

class _Clicknium():

    config = Config()
    ie = BaseWebDriver(BrowserType.IE)
    chrome = WebDriver(BrowserType.Chrome)
    firefox = WebDriver(BrowserType.FireFox)
    edge = WebDriver(BrowserType.Edge)
    window = Window()
    sap = Sap()
    java = Java()    

    @staticmethod
    def find_element(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        window_mode: Literal["auto", "topmost", "noaction"] = WindowMode.Auto
    ) -> UiElement:

        """
            Return UI element defined by the given locator.

            Remarks: 

                1.Use "Ctrl + F10" to record locator.

                2.Import window_mode type definition with " from clicknium.common.enums import * ".
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q.  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clicknium.com/documents/automation/parametric_locator.  

                window_mode: define whether to set the UI element's parent window to topmost before an action is invoked.  
                    auto: default value, means setting the window to topmost if it is not, and doing nothing if it is already topmost;  
                    topmost: always set the window to topmost;  
                    noaction: doing nothing to topmost mode.  
 
            Returns:
                UiElement object.  
        """
        ele = _InvokerService.find_element(locator, locator_variables, window_mode)
        return UiElement(ele)

    @staticmethod
    def find_elements(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        timeout: int = 30
    ) -> List[UiElement]:

        """
            Return list of all matched UI elements by the given locator.

            Remarks: 

                1.Use "Ctrl + F10" to record locator.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clicknium.com/documents/automation/parametric_locator  

                timeout: timeout for the operation, unit is second, default value is 30 seconds.  
 
            Returns:
                List of matched UiElement object.  
        """
        elements = []
        results = _InvokerService.find_elements(locator, locator_variables, timeout)
        if results:
            for element in results:
                elements.append(UiElement(element))
        return elements

    ui = find_element

    @staticmethod
    def send_hotkey(hotkey: str) -> None:
        """
            Send hotkey to the cursor's current position.
 
            Parameters:
                hotkey[Requried]: hotkey string represents one key or combined keys. For example, to represent the letter A, input string "A". To represent the letters A, B, and C, input paremeter "ABC". For special keys, please refer to [hotkeys](https://docs.microsoft.com/en-au/dotnet/api/system.windows.forms.sendkeys?view=windowsdesktop-6.0#remarks).
                                
            Returns:
                None
        """
        _InvokerService.send_hotkey(hotkey)

    @staticmethod
    def send_text(text: str) -> None:
        """
            Send text to the cursor's current position.  
 
            Parameters:

                text[Requried]: text string to be sent.  

            Returns:
                None
        """
        _InvokerService.send_text(text)

    @staticmethod
    def wait_disappear(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        wait_timeout: int = 30
    ) -> bool:
        """
            Wait for the UI element to disappear within specified timeout.  
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clicknium.com/documents/automation/parametric_locator  

                wait_timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                bool, return True if the element disappears within timeout otherwise return False.
        """ 
        result = _InvokerService.wait_disappear(locator, locator_variables, wait_timeout)
        return True if result else False

    @staticmethod
    def wait_appear(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        wait_timeout: int = 30
    ) -> UiElement:
        """
            Wait for the UI element to appear and return it within specified timeout.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clicknium.com/documents/automation/parametric_locator  

                wait_timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                UiElement object, or None if the element does not appear.  
        """      
        ele = _InvokerService.wait_appear(locator, locator_variables, wait_timeout)
        if ele:
            return UiElement(ele)
        return None

    @staticmethod
    def is_existing(
        locator: Union[_Locator, str],
        locator_variables: dict = {},
        timeout: int = 30
    ) -> bool:
        """
            Check whether the UI element exists or not.
 
            Parameters:
                locator[Required]: the visit path of locator for target UI element, eg: 'locator.chrome.bing.search_sb_form_q', locator store is chrome, and locator name is search_sb_form_q  

                locator_variables: set to initialize parameters in locator, eg: { "row": 1,  "column": 1}, more about variable, please refer to https://www.clicknium.com/documents/automation/parametric_locator  

                timeout: timeout for the operation, the unit is second, and default value is 30 seconds.  
 
            Returns:
                Return True if the UI element exists, otherwise return False.
        """        
        result = _InvokerService.is_existing(locator, locator_variables, timeout)
        return True if result else False    

    @staticmethod
    def get_screenshot(image_file: str) -> None:
        """
            Saves a screenshot of the current window to an image file
 
            Parameters:

                image_file[Required]: file path to save image
                                
            Returns:
                None
        """        
        Utils.create_file(image_file)
        image = _InvokerService.get_screenshot()    
        image.Save(image_file)
